from keras.layers import Layer
import tensorflow as tf


class OnnxLSTM(Layer):
    def __init__(self, units, return_sequences, return_state,  **kwargs):
        super().__init__(**kwargs)
        self.lstm_layer = tf.keras.layers.LSTM(units, return_sequences=return_sequences,
                                               return_state=return_state)
        self.return_state = return_state
        self.return_sequences = return_sequences

    def call(self, inputs, **kwargs):
        res = self.lstm_layer(inputs, **kwargs)
        if self.return_state:
            lstm_tensor, h_out, c_out = res
            lstm_flat = tf.keras.layers.Flatten()(lstm_tensor)
            h_flat = tf.keras.layers.Flatten()(h_out)
            c_flat = tf.keras.layers.Flatten()(c_out)
            concat_output = tf.keras.layers.Concatenate()([lstm_flat, h_flat, c_flat])
            return concat_output
        else:
            return res

    def build(self, input_shape):
        self.lstm_layer.build(input_shape)

    def get_config(self):
        config = super().get_config()
        config.update({
            "return_sequences": self.return_sequences,
            "return_state": self.return_state,
        })
        return config
